/* Avoid default max-width: 100%; to display map controls correctly */
li.wagtailgmap {
    overflow: hidden;
    -webkit-perspective: 1000;
    -moz-perspective: 1000;
    perspective: 1000;
}

li.wagtailgmap img {
    max-width: none;
}
